@@ -1,17 +1,17 @@
-#' Check consistency of editmatrix 
+#' Check consistency of edit set
 #'
 #' Applies Fourier-Motzkin elimination untill either all
 #' variables are eliminated or the editmatrix becomes obviously
 #' infeasible. The check rests on the theorem that a set of linear
 #' inequalities is infeasible if and only if  0 < -1 can be derived from it. 
 #'
-#' @param E an \code{\link{editmatrix}}
+#' @param E an \code{\link{editmatrix}} or \code{\link{editarray}}
 #' @param warn logical: should a warning be raised when system is infeasible?
 #' @return TRUE or FALSE
 #'
 #'
 #' @export
-isFeasible <- function(E, warn=TRUE){
+isFeasible <- function(E, warn=FALSE){
     ## TODO: make it return the subset of edits causing the contradiction.
     vars <- getVars(E)
     vars2 <- vars
@@ -28,3 +28,9 @@ isFeasible <- function(E, warn=TRUE){
     }
     return(feasible)
 }
+
+
+
+
+
+
